==> jc-1.4.0.tar.gz: java/util/zip/CheckedInputStream.h <==
// public class java.util.zip.CheckedInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c9e5ad57e1389f51 java_util_zip_CheckedInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_util_zip_CheckedInputStream_H_
#define _JC_java_util_zip_CheckedInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Checksum$object;

// Typedefs
typedef struct _jc_java_util_zip_CheckedInputStream$sub_refs	_jc_java_util_zip_CheckedInputStream$sub_refs;
typedef struct _jc_java_util_zip_CheckedInputStream$sub_nonrefs	_jc_java_util_zip_CheckedInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_CheckedInputStream$refs	_jc_java_util_zip_CheckedInputStream$refs;
typedef struct _jc_java_util_zip_CheckedInputStream$nonrefs	_jc_java_util_zip_CheckedInputStream$nonrefs;
typedef struct _jc_java_util_zip_CheckedInputStream$object	_jc_java_util_zip_CheckedInputStream$object;

typedef const struct _jc_java_util_zip_CheckedInputStream$vmethods	_jc_java_util_zip_CheckedInputStream$vmethods;
typedef const struct _jc_java_util_zip_CheckedInputStream$vtable	_jc_java_util_zip_CheckedInputStream$vtable;
typedef const struct _jc_java_util_zip_CheckedInputStream$vtype	_jc_java_util_zip_CheckedInputStream$vtype;

// Constructors
extern void _jc_java_util_zip_CheckedInputStream$method$_init$360ea72a427e87f3(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_zip_CheckedInputStream$method$getChecksum$344b1ffa660ffc14(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *);
extern jint _jc_java_util_zip_CheckedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *);
extern jint _jc_java_util_zip_CheckedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_byte_array *, jint, jint);
extern jlong _jc_java_util_zip_CheckedInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$getChecksum$344b1ffa660ffc14;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_zip_CheckedInputStream$vmethods {
	struct _jc_object	*(*getChecksum$344b1ffa660ffc14)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_byte_array *, jint, jint);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, jlong);
};

// Vtable
struct _jc_java_util_zip_CheckedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_CheckedInputStream$vmethods	java_util_zip_CheckedInputStream;
};

// Vtype
struct _jc_java_util_zip_CheckedInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_CheckedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_CheckedInputStream$sub_refs {
	struct _jc_object	*sum;
};

// Reference instance fields (object)
struct _jc_java_util_zip_CheckedInputStream$refs {
    _jc_java_util_zip_CheckedInputStream$sub_refs	java_util_zip_CheckedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_CheckedInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_CheckedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_CheckedInputStream$sub_nonrefs	java_util_zip_CheckedInputStream;
};

// Object instance structure
struct _jc_java_util_zip_CheckedInputStream$object {
	_jc_java_util_zip_CheckedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_CheckedInputStream$vtype	*vtype;
	_jc_java_util_zip_CheckedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_CheckedInputStream$vtype _jc_java_util_zip_CheckedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_CheckedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_CheckedInputStream$class_object;

#endif	/* _JC_java_util_zip_CheckedInputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/CheckedInputStream.h <==
// public class java.util.zip.CheckedInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c9e5ad57e1389f51 java_util_zip_CheckedInputStream

// header file dependencies
// @dep_header java_io_FilterInputStream

#include "java/io/FilterInputStream.h"

#ifndef _JC_java_util_zip_CheckedInputStream_H_
#define _JC_java_util_zip_CheckedInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_Checksum$object;

// Typedefs
typedef struct _jc_java_util_zip_CheckedInputStream$sub_refs	_jc_java_util_zip_CheckedInputStream$sub_refs;
typedef struct _jc_java_util_zip_CheckedInputStream$sub_nonrefs	_jc_java_util_zip_CheckedInputStream$sub_nonrefs;
typedef struct _jc_java_util_zip_CheckedInputStream$refs	_jc_java_util_zip_CheckedInputStream$refs;
typedef struct _jc_java_util_zip_CheckedInputStream$nonrefs	_jc_java_util_zip_CheckedInputStream$nonrefs;
typedef struct _jc_java_util_zip_CheckedInputStream$object	_jc_java_util_zip_CheckedInputStream$object;

typedef const struct _jc_java_util_zip_CheckedInputStream$vmethods	_jc_java_util_zip_CheckedInputStream$vmethods;
typedef const struct _jc_java_util_zip_CheckedInputStream$vtable	_jc_java_util_zip_CheckedInputStream$vtable;
typedef const struct _jc_java_util_zip_CheckedInputStream$vtype	_jc_java_util_zip_CheckedInputStream$vtype;

// Constructors
extern void _jc_java_util_zip_CheckedInputStream$method$_init$360ea72a427e87f3(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_zip_CheckedInputStream$method$getChecksum$344b1ffa660ffc14(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_CheckedInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_zip_CheckedInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern jlong _jc_java_util_zip_CheckedInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$getChecksum$344b1ffa660ffc14;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_zip_CheckedInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_util_zip_CheckedInputStream$vmethods {
	struct _jc_object	*(*getChecksum$344b1ffa660ffc14)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_util_zip_CheckedInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_CheckedInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_CheckedInputStream$vmethods	java_util_zip_CheckedInputStream;
};

// Vtype
struct _jc_java_util_zip_CheckedInputStream$vtype {
	_jc_type			type;
	_jc_java_util_zip_CheckedInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_CheckedInputStream$sub_refs {
	struct _jc_object	*sum;
};

// Reference instance fields (object)
struct _jc_java_util_zip_CheckedInputStream$refs {
    _jc_java_util_zip_CheckedInputStream$sub_refs	java_util_zip_CheckedInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_CheckedInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_CheckedInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_CheckedInputStream$sub_nonrefs	java_util_zip_CheckedInputStream;
};

// Object instance structure
struct _jc_java_util_zip_CheckedInputStream$object {
	_jc_java_util_zip_CheckedInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_CheckedInputStream$vtype	*vtype;
	_jc_java_util_zip_CheckedInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_CheckedInputStream$vtype _jc_java_util_zip_CheckedInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_CheckedInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_CheckedInputStream$class_object;

#endif	/* _JC_java_util_zip_CheckedInputStream_H_ */
